@@ -20,4 +20,4 @@ INNER JOIN
   ON cross_sec.subject_id = @resultSchema.@cohortTable.subject_id
 WHERE
   cohort_definition_id IN (@cohortIds)
-  AND DATEDIFF(d, cohort_start_date, cohort_end_date) > @minEraDuration
+  AND DATEDIFF(d, cohort_start_date, cohort_end_date) >= @minEraDuration
