@@ -1,40 +1,41 @@
 library(testthat)
 library(TreatmentPatterns)
 library(dplyr)
-library(CDMConnector)
 
-andromeda <- Andromeda::andromeda()
-
-con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
-
-withr::defer({
-  Andromeda::close(andromeda)
-  DBI::dbDisconnect(con, shutdown = TRUE)
-})
-
-cohorts <- data.frame(
-  cohortId = c(1, 2, 3),
-  cohortName = c("Disease X", "Drug A", "Drug B"),
-  type = c("target", "event", "event")
-)
-
-cohort_table <- tibble(
-  cohort_definition_id = c(3, 2, 1),
-  subject_id = c(1, 1, 1),
-  cohort_start_date = as.Date(c("2014-10-10", "2014-11-07", "2014-10-10")),
-  cohort_end_date = as.Date(c("2015-08-01", "2014-12-04", "2015-08-01"))
-)
-
-dplyr::copy_to(con, cohort_table, overwrite = TRUE)
-
-localCdm <- cdmFromCon(
-  con = con,
-  cdmSchema = "main",
-  writeSchema = "main",
-  cohortTables = "cohort_table"
-)
-
-cdmInterface <- TreatmentPatterns:::CDMInterface$new(cdm = localCdm)
+if (ableToRun()$CDMC) {
+  andromeda <- Andromeda::andromeda()
+  
+  con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
+  
+  withr::defer({
+    Andromeda::close(andromeda)
+    DBI::dbDisconnect(con, shutdown = TRUE)
+  })
+  
+  cohorts <- data.frame(
+    cohortId = c(1, 2, 3),
+    cohortName = c("Disease X", "Drug A", "Drug B"),
+    type = c("target", "event", "event")
+  )
+  
+  cohort_table <- tibble(
+    cohort_definition_id = c(3, 2, 1),
+    subject_id = c(1, 1, 1),
+    cohort_start_date = as.Date(c("2014-10-10", "2014-11-07", "2014-10-10")),
+    cohort_end_date = as.Date(c("2015-08-01", "2014-12-04", "2015-08-01"))
+  )
+  
+  dplyr::copy_to(con, cohort_table, overwrite = TRUE)
+  
+  localCdm <- cdmFromCon(
+    con = con,
+    cdmSchema = "main",
+    writeSchema = "main",
+    cohortTables = "cohort_table"
+  )
+  
+  cdmInterface <- TreatmentPatterns:::CDMInterface$new(cdm = localCdm)
+}
 
 test_that("Method: new", {
   expect_true(R6::is.R6(
@@ -49,6 +50,7 @@ test_that("Method: new - empty", {
 })
 
 test_that("Method: fetchMetadata", {
+  skip_if_not(ableToRun()$CDMC)
   cdmInterface$fetchMetadata(andromeda)
 
   metadata <- andromeda$metadata %>% collect()
@@ -65,6 +67,7 @@ test_that("Method: fetchMetadata", {
 })
 
 test_that("Method: fetchCohortTable", {
+  skip_if_not(ableToRun()$CDMC)
   # Update CDM with new dummy data
   cdmInterface <- TreatmentPatterns:::CDMInterface$new(
     cdm = localCdm
