@@ -1,9 +1,9 @@
 library(testthat)
 library(TreatmentPatterns)
 library(dplyr)
-library(CDMConnector)
 
 test_that("A", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -54,6 +54,7 @@ test_that("A", {
 })
 
 test_that("A-B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -106,6 +107,7 @@ test_that("A-B", {
 
 
 test_that("A-B-C", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -158,6 +160,7 @@ test_that("A-B-C", {
 })
 
 test_that("A-B+C", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -210,6 +213,7 @@ test_that("A-B+C", {
 })
 
 test_that("A+B-C", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -262,6 +266,7 @@ test_that("A+B-C", {
 })
 
 test_that("A-A+B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -314,6 +319,7 @@ test_that("A-A+B", {
 })
 
 test_that("A-B-A-B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -367,6 +373,7 @@ test_that("A-B-A-B", {
 })
 
 test_that("A-B-A", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -419,6 +426,7 @@ test_that("A-B-A", {
 })
 
 test_that("A-B-B, collapse to A-B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -471,6 +479,7 @@ test_that("A-B-B, collapse to A-B", {
 })
 
 test_that("A-B-B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -523,6 +532,7 @@ test_that("A-B-B", {
 })
 
 test_that("A+B-A", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -575,6 +585,7 @@ test_that("A+B-A", {
 })
 
 test_that("A-A-B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -627,6 +638,7 @@ test_that("A-A-B", {
 })
 
 test_that("A-A-B, collapse to A-B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -679,6 +691,7 @@ test_that("A-A-B, collapse to A-B", {
 })
 
 test_that("A+B-A+B, collapse to A+B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -732,6 +745,7 @@ test_that("A+B-A+B, collapse to A+B", {
 })
 
 test_that("A+B-A+B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -785,6 +799,7 @@ test_that("A+B-A+B", {
 })
 
 test_that("A-A+B-B", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -836,6 +851,7 @@ test_that("A-A+B-B", {
 })
 
 test_that("A-A-C-A+B+C-C", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -888,6 +904,7 @@ test_that("A-A-C-A+B+C-C", {
 })
 
 test_that("A-A+B+C-A+C-C", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -940,6 +957,7 @@ test_that("A-A+B+C-A+C-C", {
 })
 
 test_that("A-A+C-C-B+C-C", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -993,6 +1011,7 @@ test_that("A-A+C-C-B+C-C", {
 })
 
 test_that("start event == start target", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -1043,6 +1062,7 @@ test_that("start event == start target", {
 })
 
 test_that("end event == end target", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -1093,6 +1113,7 @@ test_that("end event == end target", {
 })
 
 test_that("start-end event == start-end target", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -1143,6 +1164,7 @@ test_that("start-end event == start-end target", {
 })
 
 test_that("start event < start target", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
 
   cohorts <- data.frame(
@@ -1184,6 +1206,7 @@ test_that("start event < start target", {
 })
 
 test_that("start event < start target, periodPrior = 60", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -1234,6 +1257,7 @@ test_that("start event < start target, periodPrior = 60", {
 })
 
 test_that("start event > end target", {
+  skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
   
   cohorts <- data.frame(
@@ -1273,3 +1297,58 @@ test_that("start event > end target", {
   
   DBI::dbDisconnect(con)
 })
+
+test_that("collapse A-B-B-B to A-A+B-B", {
+  skip_if_not(ableToRun()$CDMC)
+  con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
+  
+  cohorts <- data.frame(
+    cohortId = c(1, 2, 3),
+    cohortName = c("X", "A", "B"),
+    type = c("target", "event", "event")
+  )
+  
+  cohort_table <- dplyr::tribble(
+    ~cohort_definition_id, ~subject_id, ~cohort_start_date,    ~cohort_end_date,
+    1,                     5,           as.Date("2014-01-01"), as.Date("2015-12-31"),
+    2,                     5,           as.Date("2014-05-20"), as.Date("2014-08-17"),
+    3,                     5,           as.Date("2014-07-08"), as.Date("2014-08-25"),
+    3,                     5,           as.Date("2014-10-19"), as.Date("2015-02-22"),
+    3,                     5,           as.Date("2015-02-28"), as.Date("2015-09-26")
+  )
+  
+  copy_to(con, cohort_table, overwrite = TRUE)
+  
+  cdm <- cdmFromCon(con, cdmSchema = "main", writeSchema = "main", cohortTables = "cohort_table")
+  
+  andromeda <- TreatmentPatterns::computePathways(
+    cohorts = cohorts,
+    cohortTableName = 'cohort_table',
+    cdm = cdm,
+    tempEmulationSchema = NULL,
+    includeTreatments = "startDate",
+    periodPriorToIndex = 0,
+    minEraDuration = 30,
+    eraCollapseSize = 30,
+    combinationWindow = 30,
+    minPostCombinationDuration = 30,
+    filterTreatments = "All",
+    maxPathLength = 5
+  )
+  
+  tempDir <- tempdir()
+  TreatmentPatterns::export(andromeda, tempDir, minCellCount = 1)
+  
+  treatmentPaths <- read.csv(file.path(tempDir, "treatmentPathways.csv"))
+  
+  path <- treatmentPaths %>%
+    dplyr::filter(
+      .data$age == "all",
+      .data$sex == "all",
+      .data$indexYear == "all") %>%
+    dplyr::pull(.data$path)
+  
+  expect_identical(path, "A-A+B-B")
+  
+  DBI::dbDisconnect(con)
+})
